@@ -1,6 +1,6 @@
 /* -*-c-*- */
 /*
- * GNOME WM Compliance adapted for FVWM
+ * GNOME WM Compliance adapted for fvwm
  * Properties set on the root window (or desktop window)
  *
  * Even though the rest of fvwm is GPL consider this file
@@ -8,7 +8,7 @@
  * your WM GNOME compiant
  *
  * written by Raster
- * adapted for FVWM by Jay Painter <jpaint@gnu.org>
+ * adapted for fvwm by Jay Painter <jpaint@gnu.org>
  */
 #include "config.h"
 
@@ -19,8 +19,10 @@
 
 #include <X11/Xlib.h>
 #include <X11/Xmd.h>
+#include <X11/Xatom.h>
 
 #include "libs/fvwmlib.h"
+#include "libs/Parse.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
@@ -523,12 +525,13 @@ GNOME_SetHints(FvwmWindow *fwin)
 	{
 		val |= WIN_STATE_SHADED;
 	}
-	if (!is_function_allowed(F_MOVE, NULL, fwin, True, False))
+	if (!is_function_allowed(F_MOVE, NULL, fwin, RQORIG_PROGRAM_US, False))
 	{
 		val |= WIN_STATE_FIXED_POSITION;
 	}
-	XChangeProperty(dpy, FW_W(fwin), atom_set, XA_CARDINAL, 32,
-			PropModeReplace, (unsigned char *)&val, 1);
+	XChangeProperty(
+		dpy, FW_W(fwin), atom_set, XA_CARDINAL, 32, PropModeReplace,
+		(unsigned char *)&val, 1);
 
 	return;
 }
@@ -1170,7 +1173,7 @@ GNOME_ProxyButtonEvent(const XEvent *ev)
 }
 
 
-/* this is the function entered into FVWM's functions table */
+/* this is the function entered into fvwm's functions table */
 void
 CMD_GnomeButton(F_CMD_ARGS)
 {
